@@ -132,6 +132,9 @@ impl Eq for GlyphRasterConfig {}
 pub struct GlyphPosition<U: Copy + Clone = ()> {
     /// Hashable key that can be used to uniquely identify a rasterized glyph.
     pub key: GlyphRasterConfig,
+    /// The associated character that generated this glyph. A character may generate multiple
+    /// glyphs.
+    pub parent: char,
     /// The xmin of the glyph bounding box. This represents the left side of the glyph. Dimensions
     /// are in pixels, and are always whole numbers.
     pub x: f32,
@@ -154,7 +157,7 @@ pub struct GlyphPosition<U: Copy + Clone = ()> {
 pub struct TextStyle<'a, U: Copy + Clone = ()> {
     /// The text to layout.
     pub text: &'a str,
-    /// The scale of the text in pixel units.
+    /// The scale of the text in pixel units. The units of the scale are pixels per Em unit.
     pub px: f32,
     /// The font to layout the text in.
     pub font_index: usize,
@@ -405,6 +408,7 @@ impl<'a, U: Copy + Clone> Layout<U> {
                     px: style.px,
                     font_index: style.font_index,
                 },
+                parent: character,
                 x: floor(self.current_pos + metrics.bounds.xmin),
                 y,
                 width: metrics.width,
