@@ -10,11 +10,13 @@
 extern crate alloc;
 
 mod font;
+mod hash;
 /// Tools for laying out strings of text.
 pub mod layout;
 mod math;
 mod platform;
 mod raster;
+mod table;
 mod unicode;
 
 pub use crate::font::*;
